@@ -129,7 +129,7 @@ class HTTPServer(object):
 
         self._disable_tls_check = disable_tls_check
         self._ca_data = ca_data
-        self._cookies = cookies or CookieJar()
+        self._cookies = cookies if cookies is not None else CookieJar()
         self._headers = {'User-Agent': _user_agent}
         self._conn = None
 
@@ -178,7 +178,11 @@ class HTTPServer(object):
         local_connection = False
 
         try:
-            logger.debug('Performing: %s %s' % (method, full_uri))
+            if logger.is_debugging():
+                logger.debug('Request: %s %s' % (method, full_uri))
+                logger.debug('Headers:')
+                for key, value in headers.items():
+                    logger.debug('--> %s: %s' % (key, value))
 
             # if we weren't called under a `with` statement, we'll need to manage the
             # connection here.
@@ -192,8 +196,12 @@ class HTTPServer(object):
                 response = self._conn.getresponse()
                 response_body = response.read().decode('utf-8').strip()
 
-                logger.debug("Response: %s %s" % (response.status, response.reason))
-                logger.debug("--> %s" % response_body)
+                if logger.is_debugging():
+                    logger.debug("Response: %s %s" % (response.status, response.reason))
+                    logger.debug('Headers:')
+                    for key, value in response.getheaders():
+                        logger.debug('--> %s: %s' % (key, value))
+                    logger.debug("--> %s" % response_body)
             finally:
                 if local_connection:
                     self.__exit__()
@@ -234,6 +242,22 @@ class HTTPServer(object):
 
 
 class CookieJar(object):
+    @staticmethod
+    def from_dict(source):
+        if not isinstance(source, dict):
+            raise ValueError('Input must be a dictionary.')
+        keys = source.get('keys', [])
+        content = source.get('content', {})
+        if len(keys) != len(content):
+            raise ValueError('Cookie data is mismatched.')
+        for key in keys:
+            if key not in content:
+                raise ValueError('Cookie data is mismatched.')
+        result = CookieJar()
+        result._keys = keys
+        result._content = content
+        return result
+
     def __init__(self):
         self._keys = []
         self._content = {}
@@ -248,6 +272,7 @@ class CookieJar(object):
                 if morsel.key not in self._keys:
                     self._keys.append(morsel.key)
                 self._content[morsel.key] = morsel.value
+                logger.debug('--> Set cookie %s: %s' % (morsel.key, morsel.value))
 
         logger.debug('CookieJar contents: %s\n%s' % (self._keys, self._content))
 
@@ -256,6 +281,12 @@ class CookieJar(object):
         logger.debug('Cookie: %s' % result)
         return result
 
+    def as_dict(self):
+        return {
+            'keys': list(self._keys),
+            'content': self._content.copy()
+        }
+
     def __len__(self):
         return len(self._keys)
 
