@@ -1,4 +1,4 @@
-from logging import getLogger, LoggerAdapter
+from logging import getLogger, LoggerAdapter, DEBUG
 
 import click
 
@@ -22,6 +22,9 @@ class RSLogger(LoggerAdapter):
             msg = click.style(' %s' % msg, fg='green')
         return msg, kwargs
 
+    def is_debugging(self):
+        return self.isEnabledFor(DEBUG)
+
     def setLevel(self, level):
         """
         Set the specified level on the underlying logger.
